@@ -18,8 +18,7 @@ use crate::{
         html::{html_to_text, text_to_html},
         quoted_printable::QuotedPrintableDecoder,
     },
-    MessagePart, BinaryPart, InlinePart, ContentType, Message, MessageHeader, MimeHeader,
-    TextPart,
+    BinaryPart, ContentType, InlinePart, Message, MessageHeader, MessagePart, MimeHeader, TextPart,
 };
 
 use super::{fields::MessageField, header::parse_headers, message_stream::MessageStream};
@@ -55,6 +54,7 @@ fn bytes_to_string<'x>(
     if !is_utf8_safe {
         decoder_default(bytes)
     } else {
+        // SAFE: `bytes` slice is ASCII and UTF-8 safe
         (unsafe { std::str::from_utf8_unchecked(bytes) }).into()
     }
 }
@@ -130,15 +130,15 @@ impl<'x> Message<'x> {
         }
     }
 
-    /// Parses a byte slice containing the RFC5322 raw message and returns a 
+    /// Parses a byte slice containing the RFC5322 raw message and returns a
     /// `Message` struct.
-    /// 
+    ///
     /// This function never panics, a best-effort is made to parse the message and
     /// if no headers are found and empty `Message` struct is returned.
-    /// 
-    /// Note: The `parse()` function requires a mutable `[u8]` as input in order 
+    ///
+    /// Note: The `parse()` function requires a mutable `[u8]` as input in order
     /// to perform BASE64/Quoted-Printable decoding in-place.
-    /// 
+    ///
     pub fn parse(bytes: &'x mut [u8]) -> Message<'x> {
         let stream = MessageStream::new(bytes);
 
@@ -388,9 +388,7 @@ impl<'x> Message<'x> {
                         if let (Some(mut prev_message), Some(mut prev_state)) =
                             (message_stack.pop(), state_stack.pop())
                         {
-                            prev_message
-                                .attachments
-                                .push(MessagePart::Message(message));
+                            prev_message.attachments.push(MessagePart::Message(message));
                             message = prev_message;
                             prev_state.mime_boundary = state.mime_boundary;
                             state = prev_state;
@@ -466,9 +464,7 @@ impl<'x> Message<'x> {
         }
 
         while let Some(mut prev_message) = message_stack.pop() {
-            prev_message
-                .attachments
-                .push(MessagePart::Message(message));
+            prev_message.attachments.push(MessagePart::Message(message));
             message = prev_message;
         }
 
